@@ -15,8 +15,6 @@
 from abc import ABCMeta
 from abc import abstractmethod
 
-import six
-
 from neutron_lib.api import converters as lib_converters
 from neutron_lib.api import extensions
 from neutron_lib.api import validators as lib_validators
@@ -117,6 +115,7 @@ def normalize_service_graph(port_chains):
                               'is invalid: %s.' % key)
     return port_chains
 
+
 RESOURCE_ATTRIBUTE_MAP = {
     SERVICE_GRAPHS: {
         'id': {
@@ -174,9 +173,11 @@ class Servicegraph(extensions.ExtensionDescriptor):
     def get_updated(cls):
         return "2017-09-20T00:00:00-00:00"
 
-    def update_attributes_map(self, attributes):
-        super(Servicegraph, self).update_attributes_map(
-            attributes, extension_attrs_map=RESOURCE_ATTRIBUTE_MAP)
+    @classmethod
+    def update_attributes_map(cls, extended_attributes,
+                              extension_attrs_map=None):
+        super().update_attributes_map(
+            extended_attributes, extension_attrs_map=RESOURCE_ATTRIBUTE_MAP)
 
     @classmethod
     def get_resources(cls):
@@ -195,8 +196,7 @@ class Servicegraph(extensions.ExtensionDescriptor):
         return {}
 
 
-@six.add_metaclass(ABCMeta)
-class ServiceGraphPluginBase(object):
+class ServiceGraphPluginBase(metaclass=ABCMeta):
 
     def get_plugin_type(self):
         return SG_EXT
